@@ -16,7 +16,7 @@ import jsonpath_rw as jpath
 import pyisbn
 import re
 
-__version__ = '0.1.12'
+__version__ = '0.1.13'
 
 __all__ = [
     'FatRecord',
@@ -472,7 +472,7 @@ def isbn_convert(isbn_10_or_13):
         pass
 
 
-class marcdoc(object):
+class marcdoc(dict):
     """ A wrapper around an dictionary that represents a MARC record
     (finc style).
 
@@ -496,15 +496,17 @@ class marcdoc(object):
     Usage:
 
         md = marcx.marcdoc(doc)
-        isbns = ', '.join(itertools.chain(md.020a, md.020z, md.0209, md.776z))
+        isbns = ', '.join(itertools.chain(md.x020a, md.x020z, md.x0209,
+                                          md.x776z))
     """
     def __init__(self, document, default_prefix='_source', default_index='*'):
+        dict.__init__(self, document)
         self.document = document
         self.expression_cache = {}
         self.default_prefix = default_prefix
         self.default_index = default_index
 
-    def _tag_to_expression(self, tag, prefix=None, index=None):
+    def tag_to_expression(self, tag, prefix=None, index=None):
         """ Return a multivalued parser for the given tag (e.g. 020 or 700.a).
         """
         if prefix is None:
@@ -537,7 +539,7 @@ class marcdoc(object):
         try:
             tag = name[1:]
             if tag not in self.expression_cache:
-                self.expression_cache[tag] = self._tag_to_expression(tag)
+                self.expression_cache[tag] = self.tag_to_expression(tag)
             expression = self.expression_cache[tag]
             return [m.value for m in expression.find(self.document)]
         except Exception as exc:
